@@ -604,9 +604,15 @@ _bourbaki_no_complete() {
 }
 
 _bourbaki_complete_from_stdout() {
+    _bourbaki_debug "COMPLETING FROM OUTPUT OF: $@"
     local cur line
     $BASH_COMPLETION_CUR_WORD cur
-    COMPREPLY=("${COMPREPLY[@]}" $("$@" 2>/dev/null | while read line; do [ "${line#$cur}" != "$line" ] && echo "$line"; done;))
+    if [ -z "$cur" ]; then
+      COMPREPLY=("${COMPREPLY[@]}" $("$@" 2>/dev/null))
+    else
+      COMPREPLY=("${COMPREPLY[@]}" $("$@" 2>/dev/null | while read line; do [ "${line#$cur}" != "$line" ] && echo "$line"; done;))
+    fi
+    _bourbaki_debug_total_completions
 }
 
 _eval_completer() {
